# from PyQt5 import QtCore, QtGui, QtWidgets
from qtpy import QtCore, QtGui, QtWidgets


class RightPanel:
    def setupUi(self, Form: QtWidgets.QWidget) -> None:
        Form.setObjectName("Form")
        Form.resize(585, 800)
        self.layoutWidget = QtWidgets.QWidget(Form)
        self.layoutWidget.setGeometry(QtCore.QRect(150, 0, 430, 794))
        self.layoutWidget.setObjectName("layoutWidget")
        self.right_vertical_layout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.right_vertical_layout.setContentsMargins(0, 0, 0, 0)
        self.right_vertical_layout.setObjectName("right_vertical_layout")
        self.groupBox = QtWidgets.QGroupBox(self.layoutWidget)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.active_directory_line_edit = QtWidgets.QLineEdit(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.active_directory_line_edit.setFont(font)
        self.active_directory_line_edit.setAlignment(QtCore.Qt.AlignCenter)
        self.active_directory_line_edit.setReadOnly(True)
        self.active_directory_line_edit.setObjectName(
            "active_directory_line_edit"
        )
        self.horizontalLayout_11.addWidget(self.active_directory_line_edit)
        self.directory_browse_button = QtWidgets.QPushButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.directory_browse_button.setFont(font)
        self.directory_browse_button.setObjectName("directory_browse_button")
        self.horizontalLayout_11.addWidget(self.directory_browse_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.active_file_line_edit = QtWidgets.QLineEdit(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.active_file_line_edit.setFont(font)
        self.active_file_line_edit.setAlignment(QtCore.Qt.AlignCenter)
        self.active_file_line_edit.setReadOnly(True)
        self.active_file_line_edit.setObjectName("active_file_line_edit")
        self.horizontalLayout_8.addWidget(self.active_file_line_edit)
        self.filename_browse_button = QtWidgets.QPushButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.filename_browse_button.setFont(font)
        self.filename_browse_button.setObjectName("filename_browse_button")
        self.horizontalLayout_8.addWidget(self.filename_browse_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.comboBox = QtWidgets.QComboBox(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.comboBox.setFont(font)
        self.comboBox.setAutoFillBackground(False)
        self.comboBox.setEditable(False)
        self.comboBox.setCurrentText("")
        self.comboBox.setMaxVisibleItems(100)
        self.comboBox.setFrame(True)
        self.comboBox.setObjectName("comboBox")
        self.horizontalLayout_7.addWidget(self.comboBox)
        self.verticalLayout_3.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.load_button = QtWidgets.QPushButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.load_button.setFont(font)
        self.load_button.setObjectName("load_button")
        self.horizontalLayout_6.addWidget(self.load_button)
        self.scan_push_button = QtWidgets.QPushButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.scan_push_button.setFont(font)
        self.scan_push_button.setObjectName("scan_push_button")
        self.horizontalLayout_6.addWidget(self.scan_push_button)
        self.pushButton_2 = QtWidgets.QPushButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.pushButton_2.setFont(font)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_6.addWidget(self.pushButton_2)
        self.verticalLayout_3.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_9.addWidget(self.label_2)
        self.progressBar = QtWidgets.QProgressBar(self.groupBox)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setObjectName("progressBar")
        self.horizontalLayout_9.addWidget(self.progressBar)
        self.verticalLayout_3.addLayout(self.horizontalLayout_9)
        self.right_vertical_layout.addWidget(self.groupBox)
        self.groupBox_3 = QtWidgets.QGroupBox(self.layoutWidget)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.groupBox_3.setFont(font)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_4.setContentsMargins(9, 20, -1, -1)
        self.verticalLayout_4.setSpacing(6)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.live_view_push_button = QtWidgets.QPushButton(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.live_view_push_button.setFont(font)
        self.live_view_push_button.setObjectName("live_view_push_button")
        self.verticalLayout_5.addWidget(self.live_view_push_button)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.exposure_spin_box = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.exposure_spin_box.setFont(font)
        self.exposure_spin_box.setObjectName("doubleSpinBox")
        self.horizontalLayout_13.addWidget(self.exposure_spin_box)
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_13.addWidget(self.label_5)
        self.verticalLayout_5.addLayout(self.horizontalLayout_13)
        self.pushButton_19 = QtWidgets.QPushButton(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.pushButton_19.setFont(font)
        self.pushButton_19.setObjectName("pushButton_19")
        self.verticalLayout_5.addWidget(self.pushButton_19)
        self.horizontalLayout_12.addLayout(self.verticalLayout_5)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.checkBox = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox.setFont(font)
        self.checkBox.setObjectName("checkBox")
        self.verticalLayout_7.addWidget(self.checkBox)
        self.checkBox_2 = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox_2.setFont(font)
        self.checkBox_2.setObjectName("checkBox_2")
        self.verticalLayout_7.addWidget(self.checkBox_2)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.checkBox_3 = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox_3.setFont(font)
        self.checkBox_3.setObjectName("checkBox_3")
        self.gridLayout_3.addWidget(self.checkBox_3, 1, 1, 1, 1)
        self.checkBox_6 = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox_6.setFont(font)
        self.checkBox_6.setObjectName("checkBox_6")
        self.gridLayout_3.addWidget(self.checkBox_6, 1, 2, 1, 1)
        self.checkBox_4 = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox_4.setFont(font)
        self.checkBox_4.setObjectName("checkBox_4")
        self.gridLayout_3.addWidget(self.checkBox_4, 0, 1, 1, 1)
        self.checkBox_5 = QtWidgets.QCheckBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.checkBox_5.setFont(font)
        self.checkBox_5.setObjectName("checkBox_5")
        self.gridLayout_3.addWidget(self.checkBox_5, 0, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_3.addItem(spacerItem, 0, 0, 1, 1)
        self.verticalLayout_7.addLayout(self.gridLayout_3)
        self.horizontalLayout_12.addLayout(self.verticalLayout_7)
        self.verticalLayout_4.addLayout(self.horizontalLayout_12)
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox_3)
        self.groupBox_4.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.groupBox_4.setFont(font)
        self.groupBox_4.setAutoFillBackground(False)
        self.groupBox_4.setFlat(False)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.pushButton_13 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_13.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_13.setSizePolicy(sizePolicy)
        self.pushButton_13.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(
            QtGui.QPixmap("icons/fast-forward-left.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_13.setIcon(icon)
        self.pushButton_13.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_13.setObjectName("pushButton_13")
        self.gridLayout_2.addWidget(self.pushButton_13, 3, 0, 1, 1)
        self.pushButton_15 = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButton_15.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(
            QtGui.QPixmap("icons/fast-forward-down.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_15.setIcon(icon1)
        self.pushButton_15.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_15.setObjectName("pushButton_15")
        self.gridLayout_2.addWidget(self.pushButton_15, 5, 6, 1, 1)
        self.pushButton_7 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_7.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_7.setSizePolicy(sizePolicy)
        self.pushButton_7.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(
            QtGui.QPixmap("icons/play-down.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_7.setIcon(icon2)
        self.pushButton_7.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_7.setObjectName("pushButton_7")
        self.gridLayout_2.addWidget(self.pushButton_7, 4, 2, 1, 1)
        self.pushButton_16 = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButton_16.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(
            QtGui.QPixmap("icons/play-up.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_16.setIcon(icon3)
        self.pushButton_16.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_16.setObjectName("pushButton_16")
        self.gridLayout_2.addWidget(self.pushButton_16, 2, 6, 1, 1)
        self.pushButton_17 = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButton_17.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(
            QtGui.QPixmap("icons/fast-forward-up.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_17.setIcon(icon4)
        self.pushButton_17.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_17.setObjectName("pushButton_17")
        self.gridLayout_2.addWidget(self.pushButton_17, 1, 6, 1, 1)
        self.pushButton_9 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_9.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_9.setSizePolicy(sizePolicy)
        self.pushButton_9.setText("")
        self.pushButton_9.setIcon(icon4)
        self.pushButton_9.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_9.setFlat(False)
        self.pushButton_9.setObjectName("pushButton_9")
        self.gridLayout_2.addWidget(self.pushButton_9, 1, 2, 1, 1)
        self.pushButton_6 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_6.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_6.setSizePolicy(sizePolicy)
        self.pushButton_6.setText("")
        self.pushButton_6.setIcon(icon1)
        self.pushButton_6.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_6.setObjectName("pushButton_6")
        self.gridLayout_2.addWidget(self.pushButton_6, 5, 2, 1, 1)
        self.pushButton_12 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_12.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_12.setSizePolicy(sizePolicy)
        self.pushButton_12.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(
            QtGui.QPixmap("icons/play-left.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_12.setIcon(icon5)
        self.pushButton_12.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_12.setObjectName("pushButton_12")
        self.gridLayout_2.addWidget(self.pushButton_12, 3, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_4.setFont(font)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 3, 6, 1, 1)
        self.pushButton_10 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_10.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_10.setSizePolicy(sizePolicy)
        self.pushButton_10.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(
            QtGui.QPixmap("icons/play-right.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_10.setIcon(icon6)
        self.pushButton_10.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_10.setObjectName("pushButton_10")
        self.gridLayout_2.addWidget(self.pushButton_10, 3, 3, 1, 1)
        self.pushButton_11 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.pushButton_11.sizePolicy().hasHeightForWidth()
        )
        self.pushButton_11.setSizePolicy(sizePolicy)
        self.pushButton_11.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(
            QtGui.QPixmap("icons/fast-forward-right.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.On,
        )
        self.pushButton_11.setIcon(icon7)
        self.pushButton_11.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_11.setObjectName("pushButton_11")
        self.gridLayout_2.addWidget(self.pushButton_11, 3, 4, 1, 1)
        self.fine_xy_up_button = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.fine_xy_up_button.sizePolicy().hasHeightForWidth()
        )
        self.fine_xy_up_button.setSizePolicy(sizePolicy)
        self.fine_xy_up_button.setText("")
        self.fine_xy_up_button.setIcon(icon3)
        self.fine_xy_up_button.setIconSize(QtCore.QSize(24, 24))
        self.fine_xy_up_button.setObjectName("fine_xy_up_button")
        self.gridLayout_2.addWidget(self.fine_xy_up_button, 2, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_4)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_3.setFont(font)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 3, 2, 1, 1)
        self.pushButton_14 = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButton_14.setText("")
        self.pushButton_14.setIcon(icon2)
        self.pushButton_14.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_14.setObjectName("pushButton_14")
        self.gridLayout_2.addWidget(self.pushButton_14, 4, 6, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_2.addItem(spacerItem1, 3, 5, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.gridLayout_2.addItem(spacerItem2, 3, 7, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox_4)
        self.verticalLayout_11 = QtWidgets.QVBoxLayout()
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.xy_spin_box_fine = QtWidgets.QSpinBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.xy_spin_box_fine.setFont(font)
        self.xy_spin_box_fine.setMaximum(100000)
        self.xy_spin_box_fine.setObjectName("spinBox")
        self.horizontalLayout_5.addWidget(self.xy_spin_box_fine)
        self.label_7 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_5.addWidget(self.label_7)
        spacerItem3 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.horizontalLayout_5.addItem(spacerItem3)
        self.z_fine_spinbox = QtWidgets.QSpinBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.z_fine_spinbox.setFont(font)
        self.z_fine_spinbox.setMaximum(100000)
        self.z_fine_spinbox.setObjectName("spinBox_2")
        self.horizontalLayout_5.addWidget(self.z_fine_spinbox)
        self.label_6 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_5.addWidget(self.label_6)
        self.verticalLayout_11.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.xy_spin_box_coarse = QtWidgets.QSpinBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.xy_spin_box_coarse.setFont(font)
        self.xy_spin_box_coarse.setMaximum(100000)
        self.xy_spin_box_coarse.setSingleStep(1000)
        self.xy_spin_box_coarse.setObjectName("spinBox_4")
        self.horizontalLayout_14.addWidget(self.xy_spin_box_coarse)
        self.label_9 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_14.addWidget(self.label_9)
        spacerItem4 = QtWidgets.QSpacerItem(
            40,
            20,
            QtWidgets.QSizePolicy.Expanding,
            QtWidgets.QSizePolicy.Minimum,
        )
        self.horizontalLayout_14.addItem(spacerItem4)
        self.spinBox_3 = QtWidgets.QSpinBox(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.spinBox_3.setFont(font)
        self.spinBox_3.setMaximum(100000)
        self.spinBox_3.setSingleStep(1000)
        self.spinBox_3.setObjectName("spinBox_3")
        self.horizontalLayout_14.addWidget(self.spinBox_3)
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_14.addWidget(self.label_8)
        self.verticalLayout_11.addLayout(self.horizontalLayout_14)
        self.verticalLayout_4.addLayout(self.verticalLayout_11)
        self.right_vertical_layout.addWidget(self.groupBox_3)
        self.groupBox_2 = QtWidgets.QGroupBox(Form)
        self.groupBox_2.setGeometry(QtCore.QRect(0, 0, 146, 776))
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.pushButton_20 = QtWidgets.QPushButton(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.pushButton_20.setFont(font)
        self.pushButton_20.setObjectName("pushButton_20")
        self.verticalLayout_8.addWidget(self.pushButton_20)
        spacerItem5 = QtWidgets.QSpacerItem(
            20,
            40,
            QtWidgets.QSizePolicy.Minimum,
            QtWidgets.QSizePolicy.Expanding,
        )
        self.verticalLayout_8.addItem(spacerItem5)
        self.constrastGroupBox = QtWidgets.QGroupBox(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.constrastGroupBox.setFont(font)
        self.constrastGroupBox.setObjectName("constrastGroupBox")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.constrastGroupBox)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.onRadio = QtWidgets.QRadioButton(self.constrastGroupBox)
        self.onRadio.setChecked(True)
        self.onRadio.setObjectName("onRadio")
        self.verticalLayout_9.addWidget(self.onRadio)
        self.offRadio = QtWidgets.QRadioButton(self.constrastGroupBox)
        self.offRadio.setObjectName("offRadio")
        self.verticalLayout_9.addWidget(self.offRadio)
        self.verticalLayout_8.addWidget(self.constrastGroupBox)
        self.colormapGroupBox = QtWidgets.QGroupBox(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.colormapGroupBox.setFont(font)
        self.colormapGroupBox.setObjectName("colormapGroupBox")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.colormapGroupBox)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.grayscale = QtWidgets.QRadioButton(self.colormapGroupBox)
        self.grayscale.setChecked(True)
        self.grayscale.setObjectName("grayscale")
        self.verticalLayout_10.addWidget(self.grayscale)
        self.heat = QtWidgets.QRadioButton(self.colormapGroupBox)
        self.heat.setObjectName("heat")
        self.verticalLayout_10.addWidget(self.heat)
        self.threshold = QtWidgets.QRadioButton(self.colormapGroupBox)
        self.threshold.setObjectName("threshold")
        self.verticalLayout_10.addWidget(self.threshold)
        self.verticalLayout_8.addWidget(self.colormapGroupBox)

        self.retranslateUi(Form)
        self.comboBox.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox.setTitle(_translate("Form", "Scanning"))
        self.active_directory_line_edit.setText(
            _translate("Form", "Directory")
        )
        self.directory_browse_button.setText(_translate("Form", "Browse"))
        self.active_file_line_edit.setText(_translate("Form", "Filename"))
        self.filename_browse_button.setText(_translate("Form", "Browse"))
        self.load_button.setText(_translate("Form", "Load"))
        self.scan_push_button.setText(_translate("Form", "Scan"))
        self.pushButton_2.setText(_translate("Form", "Abort"))
        self.label_2.setText(_translate("Form", "Scan Progress"))
        self.groupBox_3.setTitle(_translate("Form", "Instrument Control"))
        self.live_view_push_button.setText(_translate("Form", "Live View"))
        self.label_5.setText(_translate("Form", "Exposure (ms)"))
        self.pushButton_19.setText(_translate("Form", "Autofocus"))
        self.checkBox.setText(_translate("Form", "Ring Light"))
        self.checkBox_2.setText(_translate("Form", "Scan Light"))
        self.checkBox_3.setText(_translate("Form", "B"))
        self.checkBox_6.setText(_translate("Form", "D"))
        self.checkBox_4.setText(_translate("Form", "A"))
        self.checkBox_5.setText(_translate("Form", "C"))
        self.groupBox_4.setTitle(_translate("Form", "Move"))
        self.label_4.setText(_translate("Form", "Z"))
        self.label_3.setText(_translate("Form", "X-Y"))
        self.label_7.setText(_translate("Form", "Fine step"))
        self.label_6.setText(_translate("Form", "Fine step    "))
        self.label_9.setText(_translate("Form", "Course step"))
        self.label_8.setText(_translate("Form", "Course step"))
        self.groupBox_2.setTitle(_translate("Form", "GroupBox"))
        self.pushButton_20.setText(_translate("Form", "Go To Image"))
        self.constrastGroupBox.setTitle(_translate("Form", "Contrast"))
        self.onRadio.setText(_translate("Form", "On"))
        self.offRadio.setText(_translate("Form", "Off"))
        self.colormapGroupBox.setTitle(_translate("Form", "Colormap"))
        self.grayscale.setText(_translate("Form", "Grayscale"))
        self.heat.setText(_translate("Form", "Heat"))
        self.threshold.setText(_translate("Form", "Threshold"))
